==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/gkeonprem_vmware_cluster/GkeonpremVmwareClusterNetworkConfigOutputReference.java <==
package com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:42.070Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.gkeonpremVmwareCluster.GkeonpremVmwareClusterNetworkConfigOutputReference")
public class GkeonpremVmwareClusterNetworkConfigOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected GkeonpremVmwareClusterNetworkConfigOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected GkeonpremVmwareClusterNetworkConfigOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public GkeonpremVmwareClusterNetworkConfigOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putControlPlaneV2Config(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigControlPlaneV2Config value) {
        software.amazon.jsii.Kernel.call(this, "putControlPlaneV2Config", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putDhcpIpConfig(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigDhcpIpConfig value) {
        software.amazon.jsii.Kernel.call(this, "putDhcpIpConfig", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putHostConfig(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigHostConfig value) {
        software.amazon.jsii.Kernel.call(this, "putHostConfig", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putStaticIpConfig(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigStaticIpConfig value) {
        software.amazon.jsii.Kernel.call(this, "putStaticIpConfig", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetControlPlaneV2Config() {
        software.amazon.jsii.Kernel.call(this, "resetControlPlaneV2Config", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetDhcpIpConfig() {
        software.amazon.jsii.Kernel.call(this, "resetDhcpIpConfig", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetHostConfig() {
        software.amazon.jsii.Kernel.call(this, "resetHostConfig", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetStaticIpConfig() {
        software.amazon.jsii.Kernel.call(this, "resetStaticIpConfig", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigControlPlaneV2ConfigOutputReference getControlPlaneV2Config() {
        return software.amazon.jsii.Kernel.get(this, "controlPlaneV2Config", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigControlPlaneV2ConfigOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigDhcpIpConfigOutputReference getDhcpIpConfig() {
        return software.amazon.jsii.Kernel.get(this, "dhcpIpConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigDhcpIpConfigOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigHostConfigOutputReference getHostConfig() {
        return software.amazon.jsii.Kernel.get(this, "hostConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigHostConfigOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigStaticIpConfigOutputReference getStaticIpConfig() {
        return software.amazon.jsii.Kernel.get(this, "staticIpConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigStaticIpConfigOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getVcenterNetwork() {
        return software.amazon.jsii.Kernel.get(this, "vcenterNetwork", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigControlPlaneV2Config getControlPlaneV2ConfigInput() {
        return software.amazon.jsii.Kernel.get(this, "controlPlaneV2ConfigInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigControlPlaneV2Config.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigDhcpIpConfig getDhcpIpConfigInput() {
        return software.amazon.jsii.Kernel.get(this, "dhcpIpConfigInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigDhcpIpConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigHostConfig getHostConfigInput() {
        return software.amazon.jsii.Kernel.get(this, "hostConfigInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigHostConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getPodAddressCidrBlocksInput() {
        return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(software.amazon.jsii.Kernel.get(this, "podAddressCidrBlocksInput", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getServiceAddressCidrBlocksInput() {
        return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(software.amazon.jsii.Kernel.get(this, "serviceAddressCidrBlocksInput", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigStaticIpConfig getStaticIpConfigInput() {
        return software.amazon.jsii.Kernel.get(this, "staticIpConfigInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigStaticIpConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getPodAddressCidrBlocks() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "podAddressCidrBlocks", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setPodAddressCidrBlocks(final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> value) {
        software.amazon.jsii.Kernel.set(this, "podAddressCidrBlocks", java.util.Objects.requireNonNull(value, "podAddressCidrBlocks is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getServiceAddressCidrBlocks() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "serviceAddressCidrBlocks", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setServiceAddressCidrBlocks(final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> value) {
        software.amazon.jsii.Kernel.set(this, "serviceAddressCidrBlocks", java.util.Objects.requireNonNull(value, "serviceAddressCidrBlocks is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfig getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfig value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/gkeonprem_vmware_cluster/GkeonpremVmwareClusterNetworkConfigOutputReference.java <==
package com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:16.176Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.gkeonpremVmwareCluster.GkeonpremVmwareClusterNetworkConfigOutputReference")
public class GkeonpremVmwareClusterNetworkConfigOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected GkeonpremVmwareClusterNetworkConfigOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected GkeonpremVmwareClusterNetworkConfigOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public GkeonpremVmwareClusterNetworkConfigOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putControlPlaneV2Config(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigControlPlaneV2Config value) {
        software.amazon.jsii.Kernel.call(this, "putControlPlaneV2Config", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putDhcpIpConfig(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigDhcpIpConfig value) {
        software.amazon.jsii.Kernel.call(this, "putDhcpIpConfig", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putHostConfig(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigHostConfig value) {
        software.amazon.jsii.Kernel.call(this, "putHostConfig", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putStaticIpConfig(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigStaticIpConfig value) {
        software.amazon.jsii.Kernel.call(this, "putStaticIpConfig", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetControlPlaneV2Config() {
        software.amazon.jsii.Kernel.call(this, "resetControlPlaneV2Config", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetDhcpIpConfig() {
        software.amazon.jsii.Kernel.call(this, "resetDhcpIpConfig", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetHostConfig() {
        software.amazon.jsii.Kernel.call(this, "resetHostConfig", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetStaticIpConfig() {
        software.amazon.jsii.Kernel.call(this, "resetStaticIpConfig", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetVcenterNetwork() {
        software.amazon.jsii.Kernel.call(this, "resetVcenterNetwork", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigControlPlaneV2ConfigOutputReference getControlPlaneV2Config() {
        return software.amazon.jsii.Kernel.get(this, "controlPlaneV2Config", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigControlPlaneV2ConfigOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigDhcpIpConfigOutputReference getDhcpIpConfig() {
        return software.amazon.jsii.Kernel.get(this, "dhcpIpConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigDhcpIpConfigOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigHostConfigOutputReference getHostConfig() {
        return software.amazon.jsii.Kernel.get(this, "hostConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigHostConfigOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigStaticIpConfigOutputReference getStaticIpConfig() {
        return software.amazon.jsii.Kernel.get(this, "staticIpConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigStaticIpConfigOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigControlPlaneV2Config getControlPlaneV2ConfigInput() {
        return software.amazon.jsii.Kernel.get(this, "controlPlaneV2ConfigInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigControlPlaneV2Config.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigDhcpIpConfig getDhcpIpConfigInput() {
        return software.amazon.jsii.Kernel.get(this, "dhcpIpConfigInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigDhcpIpConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigHostConfig getHostConfigInput() {
        return software.amazon.jsii.Kernel.get(this, "hostConfigInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigHostConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getPodAddressCidrBlocksInput() {
        return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(software.amazon.jsii.Kernel.get(this, "podAddressCidrBlocksInput", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getServiceAddressCidrBlocksInput() {
        return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(software.amazon.jsii.Kernel.get(this, "serviceAddressCidrBlocksInput", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigStaticIpConfig getStaticIpConfigInput() {
        return software.amazon.jsii.Kernel.get(this, "staticIpConfigInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfigStaticIpConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.String getVcenterNetworkInput() {
        return software.amazon.jsii.Kernel.get(this, "vcenterNetworkInput", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getPodAddressCidrBlocks() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "podAddressCidrBlocks", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setPodAddressCidrBlocks(final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> value) {
        software.amazon.jsii.Kernel.set(this, "podAddressCidrBlocks", java.util.Objects.requireNonNull(value, "podAddressCidrBlocks is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getServiceAddressCidrBlocks() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "serviceAddressCidrBlocks", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setServiceAddressCidrBlocks(final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> value) {
        software.amazon.jsii.Kernel.set(this, "serviceAddressCidrBlocks", java.util.Objects.requireNonNull(value, "serviceAddressCidrBlocks is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getVcenterNetwork() {
        return software.amazon.jsii.Kernel.get(this, "vcenterNetwork", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setVcenterNetwork(final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.set(this, "vcenterNetwork", java.util.Objects.requireNonNull(value, "vcenterNetwork is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfig getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.gkeonprem_vmware_cluster.GkeonpremVmwareClusterNetworkConfig value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}
